ha_material_localization_delegate library

Constants

haDateSymbols → const Map<String, Object>
A custom set of date symbols for the ha locale.
haLocaleDatePatterns → const Map<String, String>
A custom set of date patterns for the ha locale.