invalidTimeLabel property
Error message for the time picker dialog created with showTimePicker when in TimePickerEntryMode.input.
Implementation
@override
String get invalidTimeLabel => "Lokacin bai dace ba";
Error message for the time picker dialog created with showTimePicker when in TimePickerEntryMode.input.
@override
String get invalidTimeLabel => "Lokacin bai dace ba";