reorderItemDown property
The semantics label used for ReorderableListView to reorder an item in the list one space down the list.
Implementation
@override
String get reorderItemDown => r'Matsar Da Kasa';
The semantics label used for ReorderableListView to reorder an item in the list one space down the list.
@override
String get reorderItemDown => r'Matsar Da Kasa';