reorderItemRight property
The semantics label used for ReorderableListView to reorder an item in the list one space right in the list.
Implementation
@override
String get reorderItemRight => r'Matsar Da Dama';
The semantics label used for ReorderableListView to reorder an item in the list one space right in the list.
@override
String get reorderItemRight => r'Matsar Da Dama';