selectedDateLabel property
The semantics label to describe the selected date in the calendar picker invoked using showDatePicker.
Implementation
@override
String get selectedDateLabel => "Ranar da aka zaɓa";
The semantics label to describe the selected date in the calendar picker invoked using showDatePicker.
@override
String get selectedDateLabel => "Ranar da aka zaɓa";