reorderItemToEnd property
The semantics label used for SliverReorderableList to reorder an item in the list to the end of the list.
Implementation
@override
String get reorderItemToEnd => r'Matsar Da Zuwa Ƙarshe';
The semantics label used for SliverReorderableList to reorder an item in the list to the end of the list.
@override
String get reorderItemToEnd => r'Matsar Da Zuwa Ƙarshe';