reorderItemUp property
The semantics label used for SliverReorderableList to reorder an item in the list one space up the list.
Implementation
@override
String get reorderItemUp => r'Matsar Da Sama';
The semantics label used for SliverReorderableList to reorder an item in the list one space up the list.
@override
String get reorderItemUp => r'Matsar Da Sama';