hausa_localization library

Classes

HaCupertinoLocalizations
Hausa strings for the cupertino widgets.
HaMaterialLocalizations
HaWidgetLocalizations

Constants

haDateSymbols → const Map<String, Object>
A custom set of date symbols for the ha locale.
haLocaleDatePatterns → const Map<String, String>
A custom set of date patterns for the ha locale.